@@ -7,6 +7,7 @@ import os
 import socket
 from typing import Tuple, Optional
 import weakref
+import re
 
 from urllib3.exceptions import IncompleteRead
 
@@ -210,7 +211,12 @@ class S3FileSystem(AsyncFileSystem):
     version_aware : bool (False)
         Whether to support bucket versioning.  If enable this will require the
         user to have the necessary IAM permissions for dealing with versioned
-        objects.
+        objects. Note that in the event that you only need to work with the
+        latest version of objects in a versioned bucket, and do not need the
+        VersionId for those objects, you should set ``version_aware`` to False
+        for performance reasons. When set to True, filesystem instances will
+        use the S3 ListObjectVersions API call to list directory contents,
+        which requires listing all historical object versions.
     cache_regions : bool (False)
         Whether to cache bucket regions or not. Whenever a new bucket is used,
         it will first find out which region it belongs and then use the client
@@ -363,6 +369,34 @@ class S3FileSystem(AsyncFileSystem):
                 out["version_aware"] = True
         return out
 
+    def _find_bucket_key(self, s3_path):
+        """
+        This is a helper function that given an s3 path such that the path is of
+        the form: bucket/key
+        It will return the bucket and the key represented by the s3 path
+        """
+
+        _S3_ACCESSPOINT_TO_BUCKET_KEY_REGEX = re.compile(
+            r"^(?P<bucket>arn:(aws).*:s3:[a-z\-0-9]*:[0-9]{12}:accesspoint[:/][^/]+)/?"
+            r"(?P<key>.*)$"
+        )
+        _S3_OUTPOST_TO_BUCKET_KEY_REGEX = re.compile(
+            r"^(?P<bucket>arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]"
+            r"[a-zA-Z0-9\-]{1,63}[/:](bucket|accesspoint)[/:][a-zA-Z0-9\-]{1,63})[/:]?(?P<key>.*)$"
+        )
+        match = _S3_ACCESSPOINT_TO_BUCKET_KEY_REGEX.match(s3_path)
+        if match:
+            return match.group("bucket"), match.group("key")
+        match = _S3_OUTPOST_TO_BUCKET_KEY_REGEX.match(s3_path)
+        if match:
+            return match.group("bucket"), match.group("key")
+        s3_components = s3_path.split("/", 1)
+        bucket = s3_components[0]
+        s3_key = ""
+        if len(s3_components) > 1:
+            s3_key = s3_components[1]
+        return bucket, s3_key
+
     def split_path(self, path) -> Tuple[str, str, Optional[str]]:
         """
         Normalise S3 path string into bucket and key.
@@ -385,7 +419,7 @@ class S3FileSystem(AsyncFileSystem):
         if "/" not in path:
             return path, "", None
         else:
-            bucket, keypart = path.split("/", 1)
+            bucket, keypart = self._find_bucket_key(path)
             key, _, version_id = keypart.partition("?versionId=")
             return (
                 bucket,
@@ -630,7 +664,13 @@ class S3FileSystem(AsyncFileSystem):
                 logger.debug("Get directory listing page for %s" % path)
                 await self.set_session()
                 s3 = await self.get_s3(bucket)
-                pag = s3.get_paginator("list_objects_v2")
+                if self.version_aware:
+                    method = "list_object_versions"
+                    contents_key = "Versions"
+                else:
+                    method = "list_objects_v2"
+                    contents_key = "Contents"
+                pag = s3.get_paginator(method)
                 config = {}
                 if max_items is not None:
                     config.update(MaxItems=max_items, PageSize=2 * max_items)
@@ -645,10 +685,11 @@ class S3FileSystem(AsyncFileSystem):
                 dircache = []
                 async for i in it:
                     dircache.extend(i.get("CommonPrefixes", []))
-                    for c in i.get("Contents", []):
-                        c["type"] = "file"
-                        c["size"] = c["Size"]
-                        files.append(c)
+                    for c in i.get(contents_key, []):
+                        if not self.version_aware or c.get("IsLatest"):
+                            c["type"] = "file"
+                            c["size"] = c["Size"]
+                            files.append(c)
                 if dircache:
                     files.extend(
                         [
@@ -1129,12 +1170,24 @@ class S3FileSystem(AsyncFileSystem):
         if path in ["/", ""]:
             return {"name": path, "size": 0, "type": "directory"}
         version_id = _coalesce_version_id(path_version_id, version_id)
-        if not refresh and self._ls_from_cache(path) is not None:
+        if not refresh:
             out = self._ls_from_cache(path)
-            out = [o for o in out if o["name"] == path]
-            if out:
-                return out[0]
-            return {"name": path, "size": 0, "type": "directory"}
+            if out is not None:
+                if self.version_aware and version_id is not None:
+                    # If cached info does not match requested version_id,
+                    # fallback to calling head_object
+                    out = [
+                        o
+                        for o in out
+                        if o["name"] == path and version_id == o.get("VersionId")
+                    ]
+                    if out:
+                        return out[0]
+                else:
+                    out = [o for o in out if o["name"] == path]
+                    if out:
+                        return out[0]
+                    return {"name": path, "size": 0, "type": "directory"}
         if key:
             try:
                 out = await self._call_s3(
