@@ -1622,6 +1622,33 @@ def test_versions_unaware(s3):
             fo.read()
 
 
+def test_versions_dircached(s3):
+    versioned_file = versioned_bucket_name + "/dir/versioned_file"
+    s3 = S3FileSystem(
+        anon=False, version_aware=True, client_kwargs={"endpoint_url": endpoint_uri}
+    )
+    with s3.open(versioned_file, "wb") as fo:
+        fo.write(b"1")
+    first_version = fo.version_id
+    with s3.open(versioned_file, "wb") as fo:
+        fo.write(b"2")
+    second_version = fo.version_id
+    s3.find(versioned_bucket_name)
+    cached = s3.dircache[versioned_bucket_name + "/dir"][0]
+
+    assert cached.get("VersionId") == second_version
+    assert s3.info(versioned_file) == cached
+
+    assert (
+        s3.info(versioned_file, version_id=first_version).get("VersionId")
+        == first_version
+    )
+    assert (
+        s3.info(versioned_file, version_id=second_version).get("VersionId")
+        == second_version
+    )
+
+
 def test_text_io__stream_wrapper_works(s3):
     """Ensure using TextIOWrapper works."""
     s3.mkdir("bucket")
@@ -2392,3 +2419,17 @@ def test_list_del_multipart(s3):
         f.close()  # may error
     except Exception:
         pass
+
+
+def test_split_path(s3):
+    buckets = [
+        "my-test-bucket",
+        "arn:aws:s3:region:123456789012:accesspoint/my-access-point-name",
+        "arn:aws:s3-outposts:region:123456789012:outpost/outpost-id/bucket/my-test-bucket",
+        "arn:aws:s3-outposts:region:123456789012:outpost/outpost-id/accesspoint/my-accesspoint-name",
+    ]
+    test_key = "my/test/path"
+    for test_bucket in buckets:
+        bucket, key, _ = s3.split_path("s3://" + test_bucket + "/" + test_key)
+        assert bucket == test_bucket
+        assert key == test_key
